WEditor
================
.. image:: https://img.shields.io/pypi/v/weditor.svg?style=flat-square
    :target: https://pypi.python.org/pypi/weditor
.. image:: https://img.shields.io/github/stars/openatx/weditor.svg?style=social&label=Star&style=flat-square
    :target: https://github.com/openatx/weditor
.. image:: https://travis-ci.org/openatx/weditor.svg?branch=master
    :target: https://travis-ci.org/openatx/weditor

This project is subproject for smart phone test framework `AutomatorX <https://github.com/NetEaseGame/AutomatorX>`_
for easily use web browser to edit atx scripts.
This project is hosted in `github.com <https://github.com/openatx/weditor>`_

Installation
--------------

.. code-block:: bash

    pip install --pre --upgrade weditor

Usage
-----

Create Shortcut in Desktop

.. code-block:: bash

    python -m weditor --shortcut

By click shortcut or run in command line

.. code-block:: bash

    python -m weditor

This command will start a local server with port 17310,
and then open a browser tab for you to editor you code.

Port 17310 is to memorize the created day -- 2017/03/10

For Developers
--------------
`API Document <API.md>`_

LICENSE
^^^^^^^

`MIT <LICENSE>`_
